# Design Guide

The following guidelines should be followed for clearity and consistency throughout the project:

- The formatting of error messages should be consistent. An error message starts with a lowercase letter and identifiers are highlighted by double quotes.
- Private functions should be prefered over inner functions. Long inner functions can impede the comprehension of a function.
